====================
PyTables Development
====================

If you want to follow the development of PyTables and take part in it,
you may have a look at the PyTables project pages on
`GitHub <https://github.com>`_.

The source code for PyTables may be found at the `GitHub project site`_.
You can get a copy of the latest version of the source code (under
development) from the master branch of the project repository using git::

    git clone git@github.com:PyTables/PyTables.git

Also, be sure to subscribe to the `Users' Mailing List`_ and/or the
`Developers' Mailing List`_.

.. _`GitHub project site`: https://github.com/PyTables
.. _`Users' Mailing List`: https://lists.sourceforge.net/lists/listinfo/pytables-users
.. _`Developers' Mailing List`: https://groups.google.com/group/pytables-dev

Other resources for developers:

* `GitHub project site`_
* :ref:`library_reference`
* `Git Repository browser <https://github.com/PyTables/PyTables>`_
* `Issue tracker <https://github.com/PyTables/PyTables/issues>`_
* `Developers wiki <https://github.com/PyTables/PyTables/wiki>`_
* `Users' Mailing List`_
* `Developers' Mailing List`_
* Continuous Integration:

  - `master <http://hudson.openmicroscopy.org.uk/job/PyTables>`_ branch at
    OME_
  - `develop <https://jenkins.shiningpanda.com/pytables/>`_ branch at
    `Shining Panda`_
  - `all branches <https://travis-ci.org/PyTables/PyTables>`_ on `Travis-CI`_

* `Old trac site <http://www.pytables.org/trac-bck>`_

.. _OME: http://www.openmicroscopy.org
.. _`Shining Panda`: https://www.shiningpanda-ci.com
.. _`Travis-CI`: https://travis-ci.org

.. toctree::
    :maxdepth: 1

    irclogs

.. todo:: improve this section
